==> kubernetes-model-1.0.31-sources.jar: io/fabric8/openshift/api/model/ProjectFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.Map;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import java.util.HashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class ProjectFluentImpl<T extends ProjectFluent<T>> extends BaseFluent<T> implements ProjectFluent<T>{

     Project.ApiVersion apiVersion;     String kind;     VisitableBuilder<ObjectMeta, ?> metadata;     VisitableBuilder<ProjectSpec, ?> spec;     VisitableBuilder<ProjectStatus, ?> status;     Map<String, Object> additionalProperties = new HashMap();

    public Project.ApiVersion getApiVersion(){
    return this.apiVersion;
    }
    public T withApiVersion( Project.ApiVersion apiVersion){
    this.apiVersion=apiVersion; return (T) this;
    }
    public String getKind(){
    return this.kind;
    }
    public T withKind( String kind){
    this.kind=kind; return (T) this;
    }
    public ObjectMeta getMetadata(){
    return this.metadata!=null?this.metadata.build():null;
    }
    public T withMetadata( ObjectMeta metadata){
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (T) this;
    }
    public MetadataNested<T> withNewMetadata(){
    return new MetadataNestedImpl<T>();
    }
    public MetadataNested<T> withNewMetadataLike( ObjectMeta item){
    return new MetadataNestedImpl<T>(item);
    }
    public MetadataNested<T> editMetadata(){
    return withNewMetadataLike(getMetadata());
    }
    public ProjectSpec getSpec(){
    return this.spec!=null?this.spec.build():null;
    }
    public T withSpec( ProjectSpec spec){
    if (spec!=null){ this.spec= new ProjectSpecBuilder(spec); _visitables.add(this.spec);} return (T) this;
    }
    public SpecNested<T> withNewSpec(){
    return new SpecNestedImpl<T>();
    }
    public SpecNested<T> withNewSpecLike( ProjectSpec item){
    return new SpecNestedImpl<T>(item);
    }
    public SpecNested<T> editSpec(){
    return withNewSpecLike(getSpec());
    }
    public ProjectStatus getStatus(){
    return this.status!=null?this.status.build():null;
    }
    public T withStatus( ProjectStatus status){
    if (status!=null){ this.status= new ProjectStatusBuilder(status); _visitables.add(this.status);} return (T) this;
    }
    public StatusNested<T> withNewStatus(){
    return new StatusNestedImpl<T>();
    }
    public StatusNested<T> withNewStatusLike( ProjectStatus item){
    return new StatusNestedImpl<T>(item);
    }
    public StatusNested<T> editStatus(){
    return withNewStatusLike(getStatus());
    }
    public T withNewStatus( String phase){
    return withStatus(new ProjectStatus(phase));
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ProjectFluentImpl that = (ProjectFluentImpl) o;
if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
if (status != null ? !status.equals(that.status) :that.status != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<MetadataNested<N>> implements MetadataNested<N>{

        private final ObjectMetaBuilder builder;
    
             MetadataNestedImpl (){
        this.builder = new ObjectMetaBuilder(this);
        }
             MetadataNestedImpl ( ObjectMeta item){
        this.builder = new ObjectMetaBuilder(this, item);
        }
    
            public N and(){
            return (N) ProjectFluentImpl.this.withMetadata(builder.build());
        }
            public N endMetadata(){
            return and();
        }
    
}
    public class SpecNestedImpl<N> extends ProjectSpecFluentImpl<SpecNested<N>> implements SpecNested<N>{

        private final ProjectSpecBuilder builder;
    
             SpecNestedImpl (){
        this.builder = new ProjectSpecBuilder(this);
        }
             SpecNestedImpl ( ProjectSpec item){
        this.builder = new ProjectSpecBuilder(this, item);
        }
    
            public N endSpec(){
            return and();
        }
            public N and(){
            return (N) ProjectFluentImpl.this.withSpec(builder.build());
        }
    
}
    public class StatusNestedImpl<N> extends ProjectStatusFluentImpl<StatusNested<N>> implements StatusNested<N>{

        private final ProjectStatusBuilder builder;
    
             StatusNestedImpl (){
        this.builder = new ProjectStatusBuilder(this);
        }
             StatusNestedImpl ( ProjectStatus item){
        this.builder = new ProjectStatusBuilder(this, item);
        }
    
            public N and(){
            return (N) ProjectFluentImpl.this.withStatus(builder.build());
        }
            public N endStatus(){
            return and();
        }
    
}


}

==> kubernetes-model-1.0.34-sources.jar: io/fabric8/openshift/api/model/ProjectFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.Map;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import java.util.HashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class ProjectFluentImpl<T extends ProjectFluent<T>> extends BaseFluent<T> implements ProjectFluent<T>{

     Project.ApiVersion apiVersion;     String kind;     VisitableBuilder<ObjectMeta, ?> metadata;     VisitableBuilder<ProjectSpec, ?> spec;     VisitableBuilder<ProjectStatus, ?> status;     Map<String, Object> additionalProperties = new HashMap();
public ProjectFluentImpl(){
    
}
public ProjectFluentImpl( Project instance ){
    this.withApiVersion(instance.getApiVersion()); this.withKind(instance.getKind()); this.withMetadata(instance.getMetadata()); this.withSpec(instance.getSpec()); this.withStatus(instance.getStatus()); 
}

    public Project.ApiVersion getApiVersion(){
    return this.apiVersion;
    }
    public T withApiVersion( Project.ApiVersion apiVersion){
    this.apiVersion=apiVersion; return (T) this;
    }
    public String getKind(){
    return this.kind;
    }
    public T withKind( String kind){
    this.kind=kind; return (T) this;
    }
    public ObjectMeta getMetadata(){
    return this.metadata!=null?this.metadata.build():null;
    }
    public T withMetadata( ObjectMeta metadata){
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (T) this;
    }
    public MetadataNested<T> withNewMetadata(){
    return new MetadataNestedImpl<T>();
    }
    public MetadataNested<T> withNewMetadataLike( ObjectMeta item){
    return new MetadataNestedImpl<T>(item);
    }
    public MetadataNested<T> editMetadata(){
    return withNewMetadataLike(getMetadata());
    }
    public ProjectSpec getSpec(){
    return this.spec!=null?this.spec.build():null;
    }
    public T withSpec( ProjectSpec spec){
    if (spec!=null){ this.spec= new ProjectSpecBuilder(spec); _visitables.add(this.spec);} return (T) this;
    }
    public SpecNested<T> withNewSpec(){
    return new SpecNestedImpl<T>();
    }
    public SpecNested<T> withNewSpecLike( ProjectSpec item){
    return new SpecNestedImpl<T>(item);
    }
    public SpecNested<T> editSpec(){
    return withNewSpecLike(getSpec());
    }
    public ProjectStatus getStatus(){
    return this.status!=null?this.status.build():null;
    }
    public T withStatus( ProjectStatus status){
    if (status!=null){ this.status= new ProjectStatusBuilder(status); _visitables.add(this.status);} return (T) this;
    }
    public StatusNested<T> withNewStatus(){
    return new StatusNestedImpl<T>();
    }
    public StatusNested<T> withNewStatusLike( ProjectStatus item){
    return new StatusNestedImpl<T>(item);
    }
    public StatusNested<T> editStatus(){
    return withNewStatusLike(getStatus());
    }
    public T withNewStatus( String phase){
    return withStatus(new ProjectStatus(phase));
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ProjectFluentImpl that = (ProjectFluentImpl) o;
if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
if (status != null ? !status.equals(that.status) :that.status != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<MetadataNested<N>> implements MetadataNested<N>{

        private final ObjectMetaBuilder builder;
    
             MetadataNestedImpl (){
        this.builder = new ObjectMetaBuilder(this);
        }
             MetadataNestedImpl ( ObjectMeta item){
        this.builder = new ObjectMetaBuilder(this, item);
        }
    
            public N and(){
            return (N) ProjectFluentImpl.this.withMetadata(builder.build());
        }
            public N endMetadata(){
            return and();
        }
    
}
    public class SpecNestedImpl<N> extends ProjectSpecFluentImpl<SpecNested<N>> implements SpecNested<N>{

        private final ProjectSpecBuilder builder;
    
             SpecNestedImpl (){
        this.builder = new ProjectSpecBuilder(this);
        }
             SpecNestedImpl ( ProjectSpec item){
        this.builder = new ProjectSpecBuilder(this, item);
        }
    
            public N endSpec(){
            return and();
        }
            public N and(){
            return (N) ProjectFluentImpl.this.withSpec(builder.build());
        }
    
}
    public class StatusNestedImpl<N> extends ProjectStatusFluentImpl<StatusNested<N>> implements StatusNested<N>{

        private final ProjectStatusBuilder builder;
    
             StatusNestedImpl ( ProjectStatus item){
        this.builder = new ProjectStatusBuilder(this, item);
        }
             StatusNestedImpl (){
        this.builder = new ProjectStatusBuilder(this);
        }
    
            public N and(){
            return (N) ProjectFluentImpl.this.withStatus(builder.build());
        }
            public N endStatus(){
            return and();
        }
    
}


}
